=============
tcdo-pg-tools
=============


.. image:: https://img.shields.io/pypi/v/tcdo_pg_tools.svg
        :target: https://pypi.python.org/pypi/tcdo_pg_tools

.. image:: https://readthedocs.org/projects/tcdo-pg-tools/badge/?version=latest
        :target: https://tcdo-pg-tools.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Commandline tools to support proteogenomics analyses at MSK TCDO and beyond


* Free software: Apache Software License 2.0
* Documentation: https://tcdo-pg-tools.readthedocs.io.


Features
--------

* Merging RNA fusions across multiple samples which were called by CTAT-LR-Fusion or processed using FusionInspector.
  Currently also needs a metadata sheet from our internal isabl_utils package.
* calculation of AA seq coverage across multiple enzymes using fragpipe results

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
